Learn R Programming

ts2net (version 0.1.0)

dist_percentile: Returns the distance value that corresponds to the desired percentile. This function is useful when the user wants to generate networks with different distance functions but with the same link density.

Description

Returns the distance value that corresponds to the desired percentile. This function is useful when the user wants to generate networks with different distance functions but with the same link density.

Usage

dist_percentile(D, percentile = 0.1, is_D_symetric = TRUE)

Arguments

D

distance matrix

percentile

(Float) The desired percentile of lower distances.

is_D_symetric

(Boolean)

Value

Distance percentile value.