Quiroga, R. Q., Kreuz, T., & Grassberger, P. (2002). Event synchronization: a simple and fast method to measure synchronicity and time delay patterns. Physical review E, 66(4), 041904.
tsdist_es(
ets1,
ets2,
tau_max = +Inf,
method = c("quiroga", "boers"),
sig_test = FALSE,
reps = 100,
sig_level = 0.01
)Event time series 1 (one means an event, or zero otherwise)
Event time series 2 (one means an event, or zero otherwise)
The maximum tau allowed ()
"quiroga" (default) for the default co-occurrence count and normalization or "boers" for the co-occurrence count with tau_max and no normalization.
Run a significance test. Return 0 if significant or 1 otherwise.
Number of repetitions to construct the confidence interval
The significance level to test if correlation is significant.
distance
Boers, N., Goswami, B., Rheinwalt, A., Bookhagen, B., Hoskins, B., & Kurths, J. (2019). Complex networks reveal global pattern of extreme-rainfall teleconnections. Nature, 566(7744), 373-377.