The variation of information (VoI) is a distance function based on mutual information.
tsdist_voi(
ts1,
ts2,
nbins = c("sturges", "freedman-diaconis", "scott"),
method = "emp"
)Array. Time series 1
Array. Time series 2
The number of bins used for the discretization of both time series. It can be a positive integer or a string with one of the three rules "sturges" (default), "freedman-diaconis", or "scott".
The name of the entropy estimator used in the functions mutinformation() and entropy() from the infotheo package.
Distance