The functions tsdist_dir_parallel and tsdist_parts_parallel calculate part of the distance matrix D. This function merges these files and construct a distance matrix D.
dist_parts_merge(list_dfs, num_elements)A list of data frames. Each data frame should have three columns i,j, and dist.
The number of time series in the data set. The number of elements defines the number of rows ans columns in the distance matrix D.
Distance matrix D