Returns the distance value that corresponds to the desired percentile. This function is useful when the user wants to generate networks with different distance functions but with the same link density.
dist_percentile(D, percentile = 0.1, is_D_symetric = TRUE)distance matrix
(Float) The desired percentile of lower distances.
(Boolean)
Distance percentile value.